self.__BUILD_MANIFEST=function(s,c,a,e,t,u,f,n,i,j,o,r,b,d,k,l){return{__rewrites:{afterFiles:[],beforeFiles:[],fallback:[]},"/":["static/chunks/pages/index-444f1804401f04ea.js"],"/_error":["static/chunks/pages/_error-c66a4e8afc46f17b.js"],"/clusters":["static/chunks/pages/clusters-c374031237e3caa0.js"],"/clusters/[cluster]":[c,s,a,i,u,j,n,e,t,f,o,r,b,d,k,"static/chunks/1871-d7dd2203699720d5.js","static/chunks/pages/clusters/[cluster]-19c7c739be126448.js"],"/clusters/[cluster]/[job]":[c,s,a,e,t,l,"static/chunks/pages/clusters/[cluster]/[job]-1d3467f9a2a2670f.js"],"/config":["static/chunks/pages/config-718cdc365de82689.js"],"/infra":["static/chunks/pages/infra-9f85c02c9c6cae9e.js"],"/infra/[context]":["static/chunks/pages/infra/[context]-5fd3a453c079c2ea.js"],"/jobs":["static/chunks/pages/jobs-438e59578d3fe9b1.js"],"/jobs/pools/[pool]":[c,s,a,u,n,"static/chunks/8821-93c25df904a8362b.js",e,t,f,"static/chunks/pages/jobs/pools/[pool]-decca623f33f20a2.js"],"/jobs/[job]":[c,s,a,u,n,e,t,f,l,"static/chunks/pages/jobs/[job]-4e7e91a39902f166.js"],"/plugins/[...slug]":[s,"static/chunks/pages/plugins/[...slug]-449a9f5a3bb20fb3.js"],"/users":["static/chunks/pages/users-d34d44d8dc34b0d5.js"],"/volumes":["static/chunks/pages/volumes-a83ba9b38dff7ea9.js"],"/workspace/new":["static/chunks/pages/workspace/new-3f88a1c7e86a3f86.js"],"/workspaces":["static/chunks/pages/workspaces-31f50f337bd44469.js"],"/workspaces/[name]":[c,s,a,i,u,j,e,t,f,o,r,b,d,k,"static/chunks/8050-e56527859687918d.js","static/chunks/pages/workspaces/[name]-60bf69eddd69f49f.js"],sortedPages:["/","/_app","/_error","/clusters","/clusters/[cluster]","/clusters/[cluster]/[job]","/config","/infra","/infra/[context]","/jobs","/jobs/pools/[pool]","/jobs/[job]","/plugins/[...slug]","/users","/volumes","/workspace/new","/workspaces","/workspaces/[name]"]}}("static/chunks/5739-d67458fcb1386c92.js","static/chunks/616-3d59f75e2ccf9321.js","static/chunks/6130-2be46d70a38f1e82.js","static/chunks/6989-49cb7dca83a7a62d.js","static/chunks/3850-fd5696f3bbbaddae.js","static/chunks/1272-1ef0bf0237faccdb.js","static/chunks/8969-397011638fd86035.js","static/chunks/754-d0da8ab45f9509e9.js","static/chunks/6082-edabd8f6092300ce.js","static/chunks/2521-099b07cd9e4745bf.js","static/chunks/6990-944fedb5fea1cf7a.js","static/chunks/8056-c5d61f36ea3a8131.js","static/chunks/9353-7ad6bd01858556f1.js","static/chunks/733-0199b612af30df01.js","static/chunks/2109-235aa623c8726ab3.js","static/chunks/4083-0115d67c1fb57d6c.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();